![BVlain_logo](https://raw.githubusercontent.com/dembart/BVlain/master/BVlain_logo.png)

BVlain is the module for bond valence site energy calculations and is about to solve tasks related to ionic conductivity of a tracer ion in a crystal structure.

For more details, see [documentation.](https://bvlain.readthedocs.io/en/latest/index.html)

The library is under active development and it is not guaranteed that there are no bugs. If you observe not expected results, errors, please report an issue at github.

Also might be helpfull:

[cc3d repo](https://github.com/seung-lab/connected-components-3d)  
[perconet repo](https://github.com/wouterel/perconet)


